------------
-- TABLES --
------------

BEGIN WORK;

DROP TABLE SW_COMP_FILE ;

CREATE TABLE SW_COMP_FILE (
       SW_COMP_NAME VARCHAR(64) NOT NULL,
       SW_COMP_VER VARCHAR(16) NOT NULL,
       COMP_LANG_EDITION VARCHAR(16) NOT NULL,
       SW_COMP_FILENAME     VARCHAR(32) NOT NULL,
       SW_COMP_FILESIZE     INTEGER NOT NULL
);


ALTER TABLE SW_COMP_FILE
       ADD  CONSTRAINT PRIMARY KEY (SW_COMP_NAME, SW_COMP_VER, 
COMP_LANG_EDITION, SW_COMP_FILENAME, SW_COMP_FILESIZE ) ;


DROP TABLE INST_CFG_FILE ;

CREATE TABLE INST_CFG_FILE (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       CFG_FILE_NAME     VARCHAR(24) NOT NULL,
       CFG_CHG_TYPE   VARCHAR(12) NOT NULL,
       CFG_FILE_PATH     VARCHAR(64) NOT NULL,
       CFG_CHG_TIME   VARCHAR(32) NOT NULL,
       CFG_FILE_DATE     VARCHAR(32) ,
       CFG_FILE_TIME     VARCHAR(32) ,
       CFG_FILE_SIZE     INTEGER,
       FULL_FILE_NAME       VARCHAR(255) ,
       FULL_FILE_PATH       VARCHAR(255) 
);


ALTER TABLE INST_CFG_FILE
       ADD  CONSTRAINT PRIMARY KEY (HWARE_SYS_ID, CFG_FILE_NAME, CFG_CHG_TYPE, CFG_FILE_PATH, CFG_CHG_TIME);


DROP TABLE COMP_MONITOR ;

CREATE TABLE COMP_MONITOR (
       MONITOR_NAME         VARCHAR(32) NOT NULL,
       SW_COMP_NAME VARCHAR(64) NOT NULL,
       SW_COMP_VER VARCHAR(16) NOT NULL,
       COMP_LANG_EDITION VARCHAR(16) NOT NULL,
       MONITOR_PRFL_NAME VARCHAR(32) NOT NULL
);



ALTER TABLE COMP_MONITOR
       ADD CONSTRAINT PRIMARY KEY (MONITOR_NAME, SW_COMP_NAME, 
SW_COMP_VER, COMP_LANG_EDITION, MONITOR_PRFL_NAME);


DROP TABLE DOCKING_STATION ;

CREATE TABLE DOCKING_STATION (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL
);



ALTER TABLE DOCKING_STATION
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID);


DROP TABLE PERSON_SYS ;

CREATE TABLE PERSON_SYS (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       PERSON_ID            VARCHAR(32) NOT NULL
);



ALTER TABLE PERSON_SYS
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID, PERSON_ID);


DROP TABLE SW_COMP_INSTANCE ;

CREATE TABLE SW_COMP_INSTANCE (
       SW_VER_ID  VARCHAR(16) NOT NULL,
       SW_ID          VARCHAR(64) NOT NULL,
       SW_COMP_NAME VARCHAR(64) NOT NULL,
       SW_COMP_VER VARCHAR(16) NOT NULL,
       VER_LANG_EDITION VARCHAR(16) NOT NULL,
       COMP_LANG_EDITION VARCHAR(16) NOT NULL
);


ALTER TABLE SW_COMP_INSTANCE
       ADD CONSTRAINT PRIMARY KEY (SW_VER_ID, SW_ID, 
SW_COMP_NAME, SW_COMP_VER, VER_LANG_EDITION, 
COMP_LANG_EDITION);

create index SWCOMPINST_IDX on SW_COMP_INSTANCE(SW_COMP_NAME, SW_COMP_VER)
;


DROP TABLE DEV_DRV_SW ;

CREATE TABLE DEV_DRV_SW (
       DEV_CARD_ID       VARCHAR(32) NOT NULL,
       SW_VER_ID  VARCHAR(16) NOT NULL,
       SW_ID          VARCHAR(64) NOT NULL,
       VER_LANG_EDITION VARCHAR(16) NOT NULL
);



ALTER TABLE DEV_DRV_SW
       ADD CONSTRAINT PRIMARY KEY (DEV_CARD_ID, SW_VER_ID, SW_ID, 
VER_LANG_EDITION);


DROP TABLE SW_VER ;

CREATE TABLE SW_VER (
       SW_VER_ID  VARCHAR(16) NOT NULL,
       SW_ID          VARCHAR(64) NOT NULL,
       VER_LANG_EDITION VARCHAR(16) NOT NULL,
       ASSET_ID             VARCHAR(64) ,
       SW_MAJOR_VER VARCHAR(16) ,
       SW_MINOR_VER VARCHAR(16) ,
       SW_REVISION    VARCHAR(16) ,
       SW_BUILD       VARCHAR(16) ,
       SW_VER_DESCRIP VARCHAR(128) ,
       SW_VER_SER_NUM VARCHAR(32) ,
       SW_VER_ID_CODE VARCHAR(32) 
);


ALTER TABLE SW_VER
       ADD CONSTRAINT PRIMARY KEY (SW_VER_ID, SW_ID, 
VER_LANG_EDITION);


DROP TABLE INST_TAPE_DRV ;

CREATE TABLE INST_TAPE_DRV (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       TAPE_DRV_ID        VARCHAR(64) NOT NULL,
       INST_TD_ID      VARCHAR(16) NOT NULL,
       CFG_CHG_TYPE   VARCHAR(12) NOT NULL,
       CFG_CHG_TIME   VARCHAR(32) 
);


ALTER TABLE INST_TAPE_DRV
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID, TAPE_DRV_ID, INST_TD_ID, CFG_CHG_TYPE);


DROP TABLE INST_CDROM_DRV ;

CREATE TABLE INST_CDROM_DRV (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       CDROM_DRV_ID       VARCHAR(64) NOT NULL,
       INST_CD_ID      VARCHAR(16) NOT NULL,
       CFG_CHG_TYPE   VARCHAR(12) NOT NULL,
       CFG_CHG_TIME   VARCHAR(32) 
);


ALTER TABLE INST_CDROM_DRV
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID, CDROM_DRV_ID, INST_CD_ID, CFG_CHG_TYPE);


DROP TABLE INST_FLPY_DRV ;

CREATE TABLE INST_FLPY_DRV (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       FLPY_DRV_ID       VARCHAR(64) NOT NULL,
       INST_FD_ID      VARCHAR(16) NOT NULL,
       CFG_CHG_TYPE   VARCHAR(12) NOT NULL,
       CFG_CHG_TIME   VARCHAR(32) 
);


ALTER TABLE INST_FLPY_DRV
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID, FLPY_DRV_ID, INST_FD_ID, CFG_CHG_TYPE);


DROP TABLE LOG_DRV ;

CREATE TABLE LOG_DRV (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       LOG_DRV_NAME    VARCHAR(32) NOT NULL,
       HDISK_ID          VARCHAR(64) NOT NULL,
       INST_HD_ID      VARCHAR(32) NOT NULL,
       CFG_CHG_TYPE   VARCHAR(12) NOT NULL,
       LOG_DRV_SIZE_KB INTEGER,
       LOG_DRV_FREE_KB INTEGER,
       LOG_DRV_MOUNTDIR VARCHAR(16) ,
       LOG_DRV_SERNUM VARCHAR(32) ,
       LOG_DRV_VOLLABEL VARCHAR(64) ,
       LOG_DRV_FILESYS VARCHAR(16),
       CFG_CHG_TIME   VARCHAR(32)
);


ALTER TABLE LOG_DRV
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID, LOG_DRV_NAME, HDISK_ID, INST_HD_ID, CFG_CHG_TYPE);


DROP TABLE INST_HDISK ;

CREATE TABLE INST_HDISK (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       HDISK_ID          VARCHAR(64) NOT NULL,
       INST_HD_ID      VARCHAR(32) NOT NULL,
       CFG_CHG_TYPE   VARCHAR(12) NOT NULL,
       CFG_CHG_TIME   VARCHAR(32) ,
       HDISK_SER_NUM VARCHAR(32) 
);


ALTER TABLE INST_HDISK
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID, HDISK_ID, INST_HD_ID, CFG_CHG_TYPE);


DROP TABLE INST_DEV_CARD ;

CREATE TABLE INST_DEV_CARD (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       DEV_CARD_ID       VARCHAR(32) NOT NULL,
       INST_CARD_INSTANCE VARCHAR(16) NOT NULL,
       CFG_CHG_TYPE   VARCHAR(12) NOT NULL,
       CFG_CHG_TIME   VARCHAR(32) 
);


ALTER TABLE INST_DEV_CARD
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID, DEV_CARD_ID, INST_CARD_INSTANCE, CFG_CHG_TYPE);


DROP TABLE NET_NODE ;

CREATE TABLE NET_NODE (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       CFG_CHG_TYPE   VARCHAR(12) NOT NULL,
       NET_NODE_ADDR VARCHAR(32) NOT NULL,
       CFG_CHG_TIME   VARCHAR(32) ,
       NET_NODE_NAME    VARCHAR(32) ,
       NET_PROTOCOL     VARCHAR(8) 
);


ALTER TABLE NET_NODE
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID, CFG_CHG_TYPE, 
NET_NODE_ADDR);


DROP TABLE HWARE_SYS ;

CREATE TABLE HWARE_SYS (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       ASSET_ID             VARCHAR(64) ,
       LOCATION_ID          VARCHAR(32) ,
       MANUFACTURER_ID      VARCHAR(64) ,
       HWARE_SYS_SER_NUM VARCHAR(32) ,
       HWARE_SYS_DESCRIP VARCHAR(128) ,
       HWARE_ROM_VER VARCHAR(64) 
);


ALTER TABLE HWARE_SYS
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID);


DROP TABLE ASSET ;

CREATE TABLE ASSET (
       ASSET_ID             VARCHAR(64) NOT NULL
);


ALTER TABLE ASSET
       ADD CONSTRAINT PRIMARY KEY (ASSET_ID);


DROP TABLE LAT_LONG ;

CREATE TABLE LAT_LONG (
       LOCATION_ID          VARCHAR(32) NOT NULL,
       LATITUDE             VARCHAR(32) ,
       LONGITUDE            VARCHAR(32) 
);


ALTER TABLE LAT_LONG
       ADD CONSTRAINT PRIMARY KEY (LOCATION_ID);


DROP TABLE ROOM ;

CREATE TABLE ROOM (
       ROOM_FLOOR           VARCHAR(16) NOT NULL,
       ROOM_NUM          VARCHAR(16) NOT NULL,
       LOCATION_ID          VARCHAR(32) NOT NULL,
       ROOM_DESCRIP     VARCHAR(128) 
);


ALTER TABLE ROOM
       ADD CONSTRAINT PRIMARY KEY (ROOM_FLOOR, ROOM_NUM, LOCATION_ID);


DROP TABLE OFFICE_BUILDING ;

CREATE TABLE OFFICE_BUILDING (
       LOCATION_ID          VARCHAR(32) NOT NULL,
       BUILDING_ADDR     VARCHAR(32) ,
       BUILDING_DESCRIP VARCHAR(128) 
);


ALTER TABLE OFFICE_BUILDING
       ADD CONSTRAINT PRIMARY KEY (LOCATION_ID);


DROP TABLE INST_PROCESSOR ;

CREATE TABLE INST_PROCESSOR (
       HWARE_SYS_ID         VARCHAR(64) NOT NULL,
       PROCESSOR_NUM        VARCHAR(8)  NOT NULL,
       PROCESSOR_ID         VARCHAR(64) NOT NULL
);


ALTER TABLE INST_PROCESSOR
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID, PROCESSOR_NUM, PROCESSOR_ID);


DROP TABLE PROCESSOR ;

CREATE TABLE PROCESSOR (
       PROCESSOR_ID         VARCHAR(64) NOT NULL,
       MANUFACTURER_ID      VARCHAR(64) ,
       PROCESSOR_MODEL      VARCHAR(32) ,
       PROCESSOR_SPEED      INTEGER ,
       FEATURE              VARCHAR(16) ,
       STEPPING             VARCHAR(8) ,
       MODEL                VARCHAR(8) ,
       FAMILY               VARCHAR(8) ,
       VIR_MODE_EXT         VARCHAR(1),
       PAGE_SIZE_EXT        VARCHAR(1),
       TIME_STAMP_CNT       VARCHAR(1),
       MODEL_SPEC_REG       VARCHAR(1),
       PHYSICAL_ADDR_EXT    VARCHAR(1),
       MACHINE_CHK_EXCPT    VARCHAR(1),
       CMPXCHG8B_INST_SUP   VARCHAR(1),
       ON_CHIP_APIC         VARCHAR(1),
       MEM_TYPE_RANGE_REG   VARCHAR(1),
       PAGE_GLOBAL_ENABLE   VARCHAR(1),
       MACHINE_CHK_ARCH     VARCHAR(1),
       COND_MOVE_INST       VARCHAR(1),
       MMX_TECHNOLOGY       VARCHAR(1)
);


ALTER TABLE PROCESSOR
       ADD CONSTRAINT PRIMARY KEY (PROCESSOR_ID);


DROP TABLE INST_MONITOR_PRFL ;

CREATE TABLE INST_MONITOR_PRFL (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       SW_COMP_NAME VARCHAR(64) NOT NULL,
       SW_COMP_VER VARCHAR(16) NOT NULL,
       COMP_LANG_EDITION VARCHAR(16) NOT NULL,
       MONITOR_PRFL_NAME VARCHAR(32) NOT NULL
);



ALTER TABLE INST_MONITOR_PRFL
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID, SW_COMP_NAME, 
SW_COMP_VER, COMP_LANG_EDITION, MONITOR_PRFL_NAME);


DROP TABLE COMP_MONITOR_PRFL ;

CREATE TABLE COMP_MONITOR_PRFL (
       SW_COMP_NAME VARCHAR(64) NOT NULL,
       SW_COMP_VER VARCHAR(16) NOT NULL,
       COMP_LANG_EDITION VARCHAR(16) NOT NULL,
       MONITOR_PRFL_NAME VARCHAR(32) NOT NULL
);

ALTER TABLE COMP_MONITOR_PRFL
       ADD CONSTRAINT PRIMARY KEY (SW_COMP_NAME, SW_COMP_VER, 
COMP_LANG_EDITION, MONITOR_PRFL_NAME);


DROP TABLE PERSON_LOCATION ;

CREATE TABLE PERSON_LOCATION (
       PERSON_ID            VARCHAR(32) NOT NULL,
       LOCATION_ID          VARCHAR(32) NOT NULL
);

ALTER TABLE PERSON_LOCATION
       ADD CONSTRAINT PRIMARY KEY (PERSON_ID, LOCATION_ID);


DROP TABLE LOCATION ;

CREATE TABLE LOCATION (
       LOCATION_ID          VARCHAR(32) NOT NULL
);

DROP TABLE DEV_DRV ;

CREATE TABLE DEV_DRV (
       SW_ID          VARCHAR(64) NOT NULL
);


ALTER TABLE DEV_DRV
       ADD CONSTRAINT PRIMARY KEY (SW_ID);


DROP TABLE INST_MONITOR ;

CREATE TABLE INST_MONITOR (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       MONITOR_ID           VARCHAR(32) NOT NULL,
       CFG_CHG_TYPE   VARCHAR(12) NOT NULL,
       CFG_CHG_TIME   VARCHAR(32) 
);


ALTER TABLE INST_MONITOR
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID, MONITOR_ID, CFG_CHG_TYPE);


DROP TABLE INST_SW_COMP ;

CREATE TABLE INST_SW_COMP (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       SW_COMP_NAME VARCHAR(64) NOT NULL,
       SW_COMP_VER VARCHAR(16) NOT NULL,
       COMP_LANG_EDITION VARCHAR(16) NOT NULL,
       INST_FPACK_TIME VARCHAR(32) NOT NULL,
       INST_FPACK_PATH VARCHAR(255) ,
       FPACK_ACTIVATED   INTEGER,
       FPACK_ACTIV_TIME VARCHAR(32) ,
       TME_ADMIN_ID VARCHAR(64) ,
       ACTION_COMPLETED     VARCHAR(32) 
);


ALTER TABLE INST_SW_COMP
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID, SW_COMP_NAME, 
SW_COMP_VER, COMP_LANG_EDITION, INST_FPACK_TIME);


DROP TABLE SW_COMP_REL ;

CREATE TABLE SW_COMP_REL (
       COMP_REL_NAME VARCHAR(32) NOT NULL,
       COMP_RELATED_COMP VARCHAR(64) NOT NULL,
       SW_COMP_NAME VARCHAR(64) NOT NULL,
       SW_COMP_VER VARCHAR(16) NOT NULL,
       COMP_LANG_EDITION VARCHAR(16) NOT NULL
);


ALTER TABLE SW_COMP_REL
       ADD CONSTRAINT PRIMARY KEY (COMP_REL_NAME, 
COMP_RELATED_COMP, SW_COMP_NAME, SW_COMP_VER, 
COMP_LANG_EDITION);


DROP TABLE SW_COMP_DEPENDENCY ;

CREATE TABLE SW_COMP_DEPENDENCY (
       SW_COMP_NAME VARCHAR(64) NOT NULL,
       SW_COMP_VER VARCHAR(16) NOT NULL,
       COMP_LANG_EDITION VARCHAR(16) NOT NULL,
       HWARE_SYS_ID   VARCHAR(64) 
);


ALTER TABLE SW_COMP_DEPENDENCY
       ADD CONSTRAINT PRIMARY KEY (SW_COMP_NAME, SW_COMP_VER, 
COMP_LANG_EDITION);


DROP TABLE SW_COMP_TASK ;

CREATE TABLE SW_COMP_TASK (
       SW_COMP_NAME VARCHAR(64) NOT NULL,
       SW_COMP_VER VARCHAR(16) NOT NULL,
       COMP_LANG_EDITION VARCHAR(16) NOT NULL,
       TASK_NAME            VARCHAR(32) NOT NULL
);


ALTER TABLE SW_COMP_TASK
       ADD CONSTRAINT PRIMARY KEY (SW_COMP_NAME, SW_COMP_VER, 
COMP_LANG_EDITION);


DROP TABLE SW_SIG_FILE ;

CREATE TABLE SW_SIG_FILE (
       SIG_FILE_NAME  VARCHAR(32) NOT NULL,
       SIG_FILE_SIZE  INTEGER NOT NULL,
       COMP_LANG_EDITION VARCHAR(16) ,
       SW_COMP_NAME VARCHAR(64) NOT NULL,
       SW_COMP_VER VARCHAR(16) NOT NULL,
       FILE_CHECKSUM        INTEGER,
       FILE_CRC1            INTEGER,
       FILE_CRC2            INTEGER
);

ALTER TABLE SW_SIG_FILE
       ADD CONSTRAINT PRIMARY KEY (SIG_FILE_NAME, SIG_FILE_SIZE, SW_COMP_NAME, SW_COMP_VER);

create index SWSIGFILE_IDX on SW_SIG_FILE(SW_COMP_NAME, SW_COMP_VER)
;


DROP TABLE SW_COMP ;

CREATE TABLE SW_COMP (
       SW_COMP_NAME VARCHAR(64) NOT NULL,
       SW_COMP_VER VARCHAR(16) NOT NULL,
       COMP_LANG_EDITION VARCHAR(16) NOT NULL,
       SW_FPACK_ID       VARCHAR(128) ,
       MANUFACTURER_ID      VARCHAR(64) ,
       COMP_MAJOR_VER VARCHAR(16) ,
       COMP_MINOR_VER VARCHAR(16) ,
       COMP_REVISION   VARCHAR(16) ,
       SW_COMP_DESCRIP VARCHAR(128) ,
       SW_COMP_PLTFRM_OS VARCHAR(64) ,
       SW_COMP_PLTFRM_HW VARCHAR(64) ,
       SW_COMP_FUNCTION VARCHAR(16) ,
       SW_COMP_SER_NUMB VARCHAR(32) ,
       SW_COMP_ID_CODE VARCHAR(32) 
);


ALTER TABLE SW_COMP
       ADD CONSTRAINT PRIMARY KEY (SW_COMP_NAME, SW_COMP_VER, 
COMP_LANG_EDITION);


DROP TABLE SW_FPACK ;

CREATE TABLE SW_FPACK (
       SW_FPACK_ID       VARCHAR(128) NOT NULL,
       FPACK_TYPE        VARCHAR(32) NOT NULL,
       FP_SOURCEHOST        VARCHAR(64) 
);


ALTER TABLE SW_FPACK
       ADD CONSTRAINT PRIMARY KEY (SW_FPACK_ID);


DROP TABLE SW ;

CREATE TABLE SW (
       SW_ID          VARCHAR(64) NOT NULL,
       MANUFACTURER_ID      VARCHAR(64) ,
       SW_NAME        VARCHAR(64) ,
       SW_DESCRIP VARCHAR(128) 
);


ALTER TABLE SW
       ADD CONSTRAINT PRIMARY KEY (SW_ID);


DROP TABLE PC_PORTS ;

CREATE TABLE PC_PORTS (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       PC_PORT_BASE_ADDR VARCHAR(16) NOT NULL,
       CFG_CHG_TYPE   VARCHAR(12) NOT NULL,
       CFG_CHG_TIME   VARCHAR(32) ,
       PC_PORT_TYPE         VARCHAR(8) ,
       PC_PORT_NUM       VARCHAR(8) 
);


ALTER TABLE PC_PORTS
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID, PC_PORT_BASE_ADDR, CFG_CHG_TYPE);


DROP TABLE PC_MEM ;

CREATE TABLE PC_MEM (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       CFG_CHG_TYPE   VARCHAR(12) NOT NULL,
       CFG_CHG_TIME   VARCHAR(32) ,
       CONV_TOTAL_KB INTEGER,
       EXTENDED_TOTAL_KB    INTEGER,
       EXPANDED_TOTAL_KB    INTEGER
);


ALTER TABLE PC_MEM
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID, CFG_CHG_TYPE);


DROP TABLE PC_IPX_LAN_CONX ;

CREATE TABLE PC_IPX_LAN_CONX (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       PC_IPX_CONN_NAME     VARCHAR(32) NOT NULL,
       CFG_CHG_TYPE   VARCHAR(12) NOT NULL,
       CFG_CHG_TIME   VARCHAR(32) ,
       PC_IPX_CONN_NUM   VARCHAR(8) 
);


ALTER TABLE PC_IPX_LAN_CONX
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID, PC_IPX_CONN_NAME, CFG_CHG_TYPE);


DROP TABLE PC_IPX_LAN ;

CREATE TABLE PC_IPX_LAN (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       IPX_ADDR          VARCHAR(32) NOT NULL,
       CFG_CHG_TYPE   VARCHAR(12) NOT NULL,
       CFG_CHG_TIME   VARCHAR(32) ,
       IPX_LOGIN_NAME       VARCHAR(32) ,
       IPX_FULL_NAME        VARCHAR(32) 
);


ALTER TABLE PC_IPX_LAN
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID, IPX_ADDR, CFG_CHG_TYPE) ;


DROP TABLE FLPY_DRV ;

CREATE TABLE FLPY_DRV (
       FLPY_DRV_ID       VARCHAR(64) NOT NULL,
       MANUFACTURER_ID      VARCHAR(64) ,
       FLPY_DRV_TYPE     VARCHAR(16) 
);


ALTER TABLE FLPY_DRV
       ADD CONSTRAINT PRIMARY KEY (FLPY_DRV_ID);


DROP TABLE PC_DEV_DRVS ;

CREATE TABLE PC_DEV_DRVS (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       PC_DEV_DRV_NAME VARCHAR(32) NOT NULL,
       PC_DEV_DRV_ST_ADDR VARCHAR(16) NOT NULL,
       CFG_CHG_TYPE   VARCHAR(12) NOT NULL,
       CFG_CHG_TIME   VARCHAR(32) 
);


ALTER TABLE PC_DEV_DRVS
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID, PC_DEV_DRV_NAME, PC_DEV_DRV_ST_ADDR, CFG_CHG_TYPE);


DROP TABLE MONITOR ;

CREATE TABLE MONITOR (
       MONITOR_ID           VARCHAR(32) NOT NULL,
       MANUFACTURER_ID      VARCHAR(64) ,
       MONITOR_MODEL        VARCHAR(32) ,
       MONITOR_SIZE         VARCHAR(16) 
);


ALTER TABLE MONITOR
       ADD CONSTRAINT PRIMARY KEY (MONITOR_ID);


DROP TABLE INST_KEYBOARD ;

CREATE TABLE INST_KEYBOARD (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       CFG_CHG_TYPE   VARCHAR(12) NOT NULL,
       CFG_CHG_TIME   VARCHAR(32) ,
       MANUFACTURER_ID      VARCHAR(64) ,
       KEYBOARD_MODEL       VARCHAR(64) 
);


ALTER TABLE INST_KEYBOARD
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID, CFG_CHG_TYPE);


DROP TABLE HDISK ;

CREATE TABLE HDISK (
       HDISK_ID          VARCHAR(64) NOT NULL,
       MANUFACTURER_ID      VARCHAR(64) ,
       HDISK_MODEL       VARCHAR(32) ,
       HDISK_SIZE_MB     INTEGER,
       HDISK_ACCESS_SPEED INTEGER,
       HDISK_SEEK_TIME   INTEGER,
       HDISK_HEADS       INTEGER,
       HDISK_SECTORS     INTEGER,
       HDISK_CYLINDERS   INTEGER
);


ALTER TABLE HDISK
       ADD CONSTRAINT PRIMARY KEY (HDISK_ID);


DROP TABLE INST_COPROC ;

CREATE TABLE INST_COPROC (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       COPROC_MODEL         VARCHAR(24) NOT NULL,
       COPROC_TYPE          VARCHAR(24) NOT NULL
);


ALTER TABLE INST_COPROC
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID, COPROC_MODEL, COPROC_TYPE);


DROP TABLE COMMERCIAL_APP ;

CREATE TABLE COMMERCIAL_APP (
       SW_ID          VARCHAR(64) NOT NULL
);


ALTER TABLE COMMERCIAL_APP
       ADD CONSTRAINT PRIMARY KEY (SW_ID);


DROP TABLE INHOUSE_SW ;

CREATE TABLE INHOUSE_SW (
       SW_ID          VARCHAR(64) NOT NULL
);


ALTER TABLE INHOUSE_SW
       ADD CONSTRAINT PRIMARY KEY (SW_ID);


DROP TABLE OPERATING_SYS ;

CREATE TABLE OPERATING_SYS (
       SW_ID          VARCHAR(64) NOT NULL
);


ALTER TABLE OPERATING_SYS
       ADD CONSTRAINT PRIMARY KEY (SW_ID);


DROP TABLE NET_SW ;

CREATE TABLE NET_SW (
       SW_ID          VARCHAR(64) NOT NULL
);


ALTER TABLE NET_SW
       ADD CONSTRAINT PRIMARY KEY (SW_ID);


DROP TABLE RDBMS_SW ;

CREATE TABLE RDBMS_SW (
       SW_ID          VARCHAR(64) NOT NULL
);


ALTER TABLE RDBMS_SW
       ADD CONSTRAINT PRIMARY KEY (SW_ID);


DROP TABLE NW_VOLUMES ;

CREATE TABLE NW_VOLUMES (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       NWVOL_NAME           VARCHAR(32) NOT NULL,
       NWVOL_TOTAL_BLKS   INTEGER,
       NWVOL_BLK_SECTORS  INTEGER,
       NWVOL_AVAIL_BLKS INTEGER,
       NWVOL_DIR_SLOTS INTEGER,
       NWVOL_AVAIL_SLOTS INTEGER,
       NWVOL_IS_REMOVABLE   VARCHAR(16) 
);


ALTER TABLE NW_VOLUMES
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID, NWVOL_NAME);


DROP TABLE NWARE_SERVER ;

CREATE TABLE NWARE_SERVER (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       NW_DEV_NAME       VARCHAR(32) ,
       NW_VER           VARCHAR(16) ,
       NW_SUBVER        VARCHAR(16) ,
       NW_MAX_CONNS         INTEGER,
       NW_MAX_VOLS       INTEGER,
       NW_REVISION_LEVEL    VARCHAR(16) ,
       NW_SFT_LEVEL         VARCHAR(16) ,
       NW_TTS_LEVEL         VARCHAR(16) ,
       NW_MAX_CONNS_USED    INTEGER,
       NW_ACCOUNTING_VER    VARCHAR(16) ,
       NW_VAP_VER           VARCHAR(16) ,
       NW_QUEING_VER        VARCHAR(16) ,
       NW_PRINTSERVER_VER   VARCHAR(16) ,
       NW_VIRT_CONS_VER VARCHAR(16) ,
       NW_SEC_RSTRT_LEVEL VARCHAR(16) ,
       NW_INET_BRG_SUPP VARCHAR(16) ,
       NW_CLIB_MAJOR_VER    VARCHAR(16) ,
       NW_CLIB_MINOR_VER    VARCHAR(16) ,
       NW_CLIB_REVISION     VARCHAR(16) ,
       NW_SERIAL_NUM        VARCHAR(12)
);


ALTER TABLE NWARE_SERVER
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID);


DROP TABLE PC_BIOS ;

CREATE TABLE PC_BIOS (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       CFG_CHG_TYPE   VARCHAR(12) NOT NULL,
       CFG_CHG_TIME   VARCHAR(32) ,
       PC_BIOS_ASSET_INFO   VARCHAR(32) ,
       PC_BIOS_SVC_TAG  VARCHAR(32) ,
       PC_BIOS_ID_BYTES     VARCHAR(32) ,
       PC_BIOS_DATE         VARCHAR(32) 
);


ALTER TABLE PC_BIOS
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID, CFG_CHG_TYPE);


DROP TABLE DESKTOP_PC ;

CREATE TABLE DESKTOP_PC (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL
);


ALTER TABLE DESKTOP_PC
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID);


DROP TABLE DISK_FARM ;

CREATE TABLE DISK_FARM (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL
);


ALTER TABLE DISK_FARM
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID);


DROP TABLE TAPE_DRV ;

CREATE TABLE TAPE_DRV (
       TAPE_DRV_ID        VARCHAR(64) NOT NULL,
       MANUFACTURER_ID      VARCHAR(64) ,
       TAPE_DRV_MODEL     VARCHAR(32) 
);


ALTER TABLE TAPE_DRV
       ADD CONSTRAINT PRIMARY KEY (TAPE_DRV_ID);


DROP TABLE CDROM_DRV ;

CREATE TABLE CDROM_DRV (
       CDROM_DRV_ID       VARCHAR(64) NOT NULL,
       MANUFACTURER_ID      VARCHAR(64) ,
       CDROM_DRV_MODEL    VARCHAR(32) 
);


ALTER TABLE CDROM_DRV
       ADD CONSTRAINT PRIMARY KEY (CDROM_DRV_ID);


DROP TABLE DEV_CARD ;

CREATE TABLE DEV_CARD (
       DEV_CARD_ID       VARCHAR(32) NOT NULL,
       MANUFACTURER_ID      VARCHAR(64) 
);


ALTER TABLE DEV_CARD
       ADD CONSTRAINT PRIMARY KEY (DEV_CARD_ID);


DROP TABLE INST_MOUSE ;

CREATE TABLE INST_MOUSE (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       CFG_CHG_TYPE   VARCHAR(12) NOT NULL,
       CFG_CHG_TIME   VARCHAR(32) ,
       MANUFACTURER_ID      VARCHAR(64) ,
       MOUSE_BUTTONS        INTEGER,
       MOUSE_DRV_VER  VARCHAR(16) ,
       MOUSE_INT_LINE VARCHAR(16),
       MOUSE_MODEL     VARCHAR(64) 
);


ALTER TABLE INST_MOUSE
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID, CFG_CHG_TYPE);


DROP TABLE MANUFACTURER ;

CREATE TABLE MANUFACTURER (
       MANUFACTURER_ID      VARCHAR(64) NOT NULL,
       MANUFACTURER_NAME    VARCHAR(32) 
);


ALTER TABLE MANUFACTURER
       ADD CONSTRAINT PRIMARY KEY (MANUFACTURER_ID);


DROP TABLE PERSON ;

CREATE TABLE PERSON (
       PERSON_ID            VARCHAR(32) NOT NULL,
       PERSON_FIRSTNAME     VARCHAR(32) ,
       PERSON_LASTNAME      VARCHAR(32) 
);


ALTER TABLE PERSON
       ADD CONSTRAINT PRIMARY KEY (PERSON_ID);


DROP TABLE PERIPHERAL_SYS ;

CREATE TABLE PERIPHERAL_SYS (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL
);


ALTER TABLE PERIPHERAL_SYS
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID);


DROP TABLE INST_PRINTER ;

CREATE TABLE INST_PRINTER (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       PRINTER_ID           VARCHAR(64) NOT NULL,
       INST_PR_ID      VARCHAR(32) NOT NULL,
       CFG_CHG_TYPE   VARCHAR(12) NOT NULL,
       CFG_CHG_TIME   VARCHAR(32) ,
       LOCATION       VARCHAR(128) ,
       DRIVER_NAME    VARCHAR(64) ,
       DRIVER_VERSION   VARCHAR(32) ,
       PORT_NAME        VARCHAR(16)
);


ALTER TABLE INST_PRINTER
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID, PRINTER_ID, INST_PR_ID, CFG_CHG_TYPE);


DROP TABLE INST_RWOPT_DRV ;

CREATE TABLE INST_RWOPT_DRV (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       RWOPT_DRV_ID   VARCHAR(64) NOT NULL,
       INST_RW_ID      VARCHAR(32) NOT NULL,
       CFG_CHG_TYPE   VARCHAR(12) NOT NULL,
       CFG_CHG_TIME   VARCHAR(32) 
);


ALTER TABLE INST_RWOPT_DRV
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID, RWOPT_DRV_ID, INST_RW_ID, CFG_CHG_TYPE);


DROP TABLE REFERRED_SYS ;

CREATE TABLE REFERRED_SYS (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       REFERRED_SYS_ID   VARCHAR(64) NOT NULL
);


ALTER TABLE REFERRED_SYS
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID, REFERRED_SYS_ID);


DROP TABLE COMPUTER_SYS_MEM ;

CREATE TABLE COMPUTER_SYS_MEM (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       PHYSICAL_MEM_KB   INTEGER,
       PHYSICAL_MEM_DESC VARCHAR(32) ,
       PAGING_SPACE_KB      INTEGER,
       PAGING_SPACE_DESC    VARCHAR(32),
       TOTAL_VIR_MEM_KB     INTEGER
);


ALTER TABLE COMPUTER_SYS_MEM
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID);


DROP TABLE INST_UNKNOWN_FILE ;

CREATE TABLE INST_UNKNOWN_FILE (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       INST_FILE_NAME  VARCHAR(24) NOT NULL,
       INST_FILE_SIZE  INTEGER NOT NULL,
       INST_FILE_PATH  VARCHAR(108) NOT NULL,
       INST_FILE_DATE  VARCHAR(10) NOT NULL,
       INST_FILE_TIME  VARCHAR(8) NOT NULL,
       CFG_CHG_TYPE   VARCHAR(12) NOT NULL,
       CFG_CHG_TIME   VARCHAR(32) ,
       FULL_FILE_PATH       VARCHAR(255) ,
       FULL_FILE_NAME       VARCHAR(255) 
);


ALTER TABLE INST_UNKNOWN_FILE
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID, INST_FILE_NAME, 
INST_FILE_SIZE, INST_FILE_PATH, INST_FILE_DATE, 
INST_FILE_TIME, CFG_CHG_TYPE);


DROP TABLE COMPUTER_SYS ;

CREATE TABLE COMPUTER_SYS (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       COMPUTER_SCANTIME    VARCHAR(32) ,
       TME_OBJECT_ID        VARCHAR(128) ,
       TME_OBJECT_LABEL     VARCHAR(32) ,
       BOOTED_OS_NAME       VARCHAR(16) ,
       BOOTED_OS_VER    VARCHAR(16) ,
       COMPUTER_MODEL       VARCHAR(32) ,
       COMPUTER_ARCH VARCHAR(32) ,
       IS_A_REFERENCE_SYS INTEGER,
       COMPUTER_BOOT_TIME   VARCHAR(32) ,
       COMPUTER_ALIAS       VARCHAR(32) ,
       COMPUTER_KRNL_VER VARCHAR(128) ,
       COMPUTER_KRNL_ARCH VARCHAR(32) 
);


ALTER TABLE COMPUTER_SYS
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID);


DROP TABLE NET_CARD ;

CREATE TABLE NET_CARD (
       DEV_CARD_ID       VARCHAR(32) NOT NULL,
       NET_CARD_MODEL    VARCHAR(64) 
);


ALTER TABLE NET_CARD
       ADD CONSTRAINT PRIMARY KEY (DEV_CARD_ID);


DROP TABLE SOUND_CARD ;

CREATE TABLE SOUND_CARD (
       DEV_CARD_ID       VARCHAR(32) NOT NULL,
       SOUND_CARD_MODEL     VARCHAR(32) 
);


ALTER TABLE SOUND_CARD
       ADD CONSTRAINT PRIMARY KEY (DEV_CARD_ID);


DROP TABLE FMODEM_CARD ;

CREATE TABLE FMODEM_CARD (
       DEV_CARD_ID       VARCHAR(32) NOT NULL,
       FMODEM_CARD_MODEL  VARCHAR(32) 
);


ALTER TABLE FMODEM_CARD
       ADD CONSTRAINT PRIMARY KEY (DEV_CARD_ID);


DROP TABLE VID_CARD ;

CREATE TABLE VID_CARD (
       DEV_CARD_ID       VARCHAR(32) NOT NULL,
       VID_CARD_MODEL     VARCHAR(32) ,
       VID_CARD_BIOS      VARCHAR(64) ,
       VESA_SUPP         VARCHAR(8) ,
       VESA_VER         VARCHAR(8) ,
       VESA_OEM_NAME        VARCHAR(32) ,
       VID_DAC_TYPE       VARCHAR(32) ,
       VID_MEM         VARCHAR(32) ,
       VID_RES     VARCHAR(32) ,
       VID_COLORS         VARCHAR(32) ,
       VID_BIOS_RELDATE VARCHAR(32) 
);


ALTER TABLE VID_CARD
       ADD CONSTRAINT PRIMARY KEY (DEV_CARD_ID);


DROP TABLE CNTRL_CARD ;

CREATE TABLE CNTRL_CARD (
       DEV_CARD_ID       VARCHAR(32) NOT NULL,
       CNTRL_CARD_MODEL VARCHAR(32) 
);

ALTER TABLE CNTRL_CARD
       ADD CONSTRAINT PRIMARY KEY (DEV_CARD_ID);


DROP TABLE IO_CARD ;

CREATE TABLE IO_CARD (
       DEV_CARD_ID       VARCHAR(32) NOT NULL,
       IO_CARD_MODEL        VARCHAR(32) 
);


ALTER TABLE IO_CARD
       ADD CONSTRAINT PRIMARY KEY (DEV_CARD_ID);


DROP TABLE CFG_CHG_HIST ;

CREATE TABLE CFG_CHG_HIST (
       CFG_CHG_TYPE   VARCHAR(12) NOT NULL,
       CFG_CHG_TIME   VARCHAR(32) NOT NULL,
       CFG_CHG_DESC   VARCHAR(32) 
);


ALTER TABLE CFG_CHG_HIST
       ADD CONSTRAINT PRIMARY KEY (CFG_CHG_TYPE, CFG_CHG_TIME);


DROP TABLE NT_INFO ;

CREATE TABLE NT_INFO (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       NT_CURRENT_BUILD     VARCHAR(32) ,
       NT_CURRENT_TYPE      VARCHAR(32) ,
       NT_CURRENT_VER   VARCHAR(32) ,
       NT_REG_ORG           VARCHAR(32) ,
       NT_REG_USER          VARCHAR(32) ,
       NT_SYS_ROOT       VARCHAR(32) ,
       NT_SVC_PACK      VARCHAR(32) ,
       NT_INSTALL_DATE      VARCHAR(32) 
);


ALTER TABLE NT_INFO
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID);


DROP TABLE INST_OS_DETAILS ;

CREATE TABLE INST_OS_DETAILS (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL,
       NAME                 VARCHAR(32) NOT NULL,
       DESCRIP          VARCHAR(64) NOT NULL,
       VER_LEVEL        VARCHAR(32) NOT NULL,
       CFG_CHG_TYPE   VARCHAR(12) NOT NULL,
       CFG_CHG_TIME   VARCHAR(32) 
);


ALTER TABLE INST_OS_DETAILS
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID, NAME, DESCRIP, VER_LEVEL, 
CFG_CHG_TYPE);


DROP TABLE UNIX_SERVER ;

CREATE TABLE UNIX_SERVER (
       HWARE_SYS_ID   VARCHAR(64) NOT NULL
);


ALTER TABLE UNIX_SERVER
       ADD CONSTRAINT PRIMARY KEY (HWARE_SYS_ID);


DROP TABLE QUERY_VIEWS ;

CREATE TABLE QUERY_VIEWS (
       VIEW_NAME            VARCHAR(64) NOT NULL
);


ALTER TABLE QUERY_VIEWS
       ADD CONSTRAINT PRIMARY KEY (VIEW_NAME);


DROP TABLE QUERY_DOMAINS ;

CREATE TABLE QUERY_DOMAINS (
       TABLE_NAME           VARCHAR(64) NOT NULL,
       COLUMN_NAME          VARCHAR(64) NOT NULL,
       DOMAIN_VALUE         VARCHAR(64) NOT NULL
);


ALTER TABLE QUERY_DOMAINS
       ADD CONSTRAINT PRIMARY KEY (TABLE_NAME, COLUMN_NAME, DOMAIN_VALUE);


DROP TABLE RWOPT_DRV ;

CREATE TABLE RWOPT_DRV (
       RWOPT_DRV_ID   VARCHAR(64) NOT NULL,
       MANUFACTURER_ID      VARCHAR(64) ,
       RWOPT_DRV_MODEL VARCHAR(32) 
);


ALTER TABLE RWOPT_DRV
       ADD CONSTRAINT PRIMARY KEY (RWOPT_DRV_ID);


DROP TABLE PRINTER ;

CREATE TABLE PRINTER (
       PRINTER_ID           VARCHAR(64) NOT NULL,
       PRINTER_MODEL        VARCHAR(32) ,
       MANUFACTURER_ID      VARCHAR(64) 
);


ALTER TABLE PRINTER
       ADD CONSTRAINT PRIMARY KEY (PRINTER_ID);

drop table TAG
;

create table TAG (
       TAG_NAME varchar(64) not null,
       TAG_TYPE varchar(16) not null,
       STATUS   varchar(16)
)
;

alter table TAG
add constraint 
primary key (TAG_NAME, TAG_TYPE)
;

drop table POL_REG_STRUCTURE
;

drop table POL_REG_MEMBER
;

drop table POLICY_REGION
;

create table POLICY_REGION (
       REGION_ID varchar(64) not null,
       TMR_LABEL varchar(32) not null,
       REGION_NAME varchar(64)
)
;

alter table POLICY_REGION
add constraint 
primary key (REGION_ID, TMR_LABEL)
;

create table POL_REG_MEMBER (
       REGION_ID varchar(64) not null,
       TMR_LABEL varchar(32) not null,
       HWARE_SYS_ID varchar(64) not null
)
;

alter table POL_REG_MEMBER
add constraint 
primary key (REGION_ID, TMR_LABEL, HWARE_SYS_ID)
;

create table POL_REG_STRUCTURE (
       PARENT_REGION_ID varchar(64) not null,
       PARENT_TMR_LABEL varchar(32) not null,
       CHILD_REGION_ID  varchar(64) not null,
       CHILD_TMR_LABEL  varchar(32) not null
)
;

alter table POL_REG_STRUCTURE
add constraint 
primary key (PARENT_REGION_ID, PARENT_TMR_LABEL,
             CHILD_REGION_ID, CHILD_TMR_LABEL)
;

alter table POL_REG_MEMBER
add constraint 
foreign key (REGION_ID, TMR_LABEL)
references POLICY_REGION (REGION_ID, TMR_LABEL)
on delete cascade
;

alter table POL_REG_STRUCTURE
add constraint 
foreign key (PARENT_REGION_ID, PARENT_TMR_LABEL)
references POLICY_REGION (REGION_ID, TMR_LABEL)
on delete cascade
;

alter table POL_REG_STRUCTURE
add constraint 
foreign key (CHILD_REGION_ID, CHILD_TMR_LABEL)
references POLICY_REGION (REGION_ID, TMR_LABEL)
on delete cascade
;

drop table INST_BIOS
;

create table INST_BIOS (
      HWARE_SYS_ID      varchar(64)  not null,
      BIOS_ID           varchar(128) not null,
      BIOS_ID_BYTES     varchar(16),
      BIOS_DATE         varchar(16),
      BIOS_STRING       varchar(128),
      HW_MANUFACTURER   varchar(32),
      BIOS_MANUFACTURER varchar(32),
      BIOS_MODEL        varchar(32),
      CFG_CHG_TYPE      varchar(12)  not null,
      CFG_CHG_TIME      varchar(32)
)
;

alter table INST_BIOS
add constraint 
primary key (HWARE_SYS_ID, CFG_CHG_TYPE)
;

drop table INST_SW_VER
;

create table INST_SW_VER (
       HWARE_SYS_ID       varchar(64) not null,
       SW_VER_ID          varchar(16) not null,
       SW_ID              varchar(64) not null,
       VER_LANG_EDITION   varchar(16),
       INST_VER_PATH      varchar(64),
       CFG_CHG_TYPE       varchar(12) not null,
       CFG_CHG_TIME       varchar(32)
)
;

alter table INST_SW_VER
add constraint 
primary key (HWARE_SYS_ID, SW_VER_ID, SW_ID, CFG_CHG_TYPE)
;

COMMIT WORK;

-----------
-- VIEWS --
-----------

BEGIN WORK;

DROP VIEW user_tab_columns;
 
DROP TABLE infx_col_map;
CREATE TABLE infx_col_map
(
    COL_TYPE SMALLINT NOT NULL,
    TYPE_NAME VARCHAR(32) NOT NULL,
    ALLOW_NULL CHAR(1) NOT NULL 
);

INSERT INTO infx_col_map
    ( COL_TYPE, TYPE_NAME, ALLOW_NULL )
VALUES
    (0, 'CHAR', 'T');

INSERT INTO infx_col_map
    ( COL_TYPE, TYPE_NAME, ALLOW_NULL )
VALUES
    (1, 'SMALLINT', 'T');

INSERT INTO infx_col_map
    ( COL_TYPE, TYPE_NAME, ALLOW_NULL )
VALUES
    (2, 'INTEGER', 'T');

INSERT INTO infx_col_map
    ( COL_TYPE, TYPE_NAME, ALLOW_NULL )
VALUES
    (3, 'FLOAT', 'T');

INSERT INTO infx_col_map
    ( COL_TYPE, TYPE_NAME, ALLOW_NULL )
VALUES
    (4, 'SMALLFLOAT', 'T');

INSERT INTO infx_col_map
    ( COL_TYPE, TYPE_NAME, ALLOW_NULL )
VALUES
    (5, 'DECIMAL', 'T');

INSERT INTO infx_col_map
    ( COL_TYPE, TYPE_NAME, ALLOW_NULL )
VALUES
    (6, 'SERIAL', 'T');

INSERT INTO infx_col_map
    ( COL_TYPE, TYPE_NAME, ALLOW_NULL )
VALUES
    (7, 'DATE', 'T');

INSERT INTO infx_col_map
    ( COL_TYPE, TYPE_NAME, ALLOW_NULL )
VALUES
    (8, 'MONEY', 'T');

INSERT INTO infx_col_map
    ( COL_TYPE, TYPE_NAME, ALLOW_NULL )
VALUES
    (10, 'DATETIME', 'T');

INSERT INTO infx_col_map
    ( COL_TYPE, TYPE_NAME, ALLOW_NULL )
VALUES
    (11, 'BYTE', 'T');

INSERT INTO infx_col_map
    ( COL_TYPE, TYPE_NAME, ALLOW_NULL )
VALUES
    (12, 'TEXT', 'T');

INSERT INTO infx_col_map
    ( COL_TYPE, TYPE_NAME, ALLOW_NULL )
VALUES
    (13, 'VARCHAR', 'T');

INSERT INTO infx_col_map
    ( COL_TYPE, TYPE_NAME, ALLOW_NULL )
VALUES
    (14, 'INTERVAL', 'T');

INSERT INTO infx_col_map
    ( COL_TYPE, TYPE_NAME, ALLOW_NULL )
VALUES
    (15, 'NCHAR', 'T');

INSERT INTO infx_col_map
    ( COL_TYPE, TYPE_NAME, ALLOW_NULL )
VALUES
    (16, 'NVARCHAR', 'T');

INSERT INTO infx_col_map
    ( COL_TYPE, TYPE_NAME, ALLOW_NULL )
VALUES
    (257, 'SMALLINT', 'F');

INSERT INTO infx_col_map
    ( COL_TYPE, TYPE_NAME, ALLOW_NULL )
VALUES
    (258, 'INTEGER', 'F');

INSERT INTO infx_col_map
    ( COL_TYPE, TYPE_NAME, ALLOW_NULL )
VALUES
    (259, 'FLOAT', 'F');

INSERT INTO infx_col_map
    ( COL_TYPE, TYPE_NAME, ALLOW_NULL )
VALUES
    (260, 'SMALLFLOAT', 'F');

INSERT INTO infx_col_map
    ( COL_TYPE, TYPE_NAME, ALLOW_NULL )
VALUES
    (261, 'DECIMAL', 'F');

INSERT INTO infx_col_map
    ( COL_TYPE, TYPE_NAME, ALLOW_NULL )
VALUES
    (262, 'SERIAL', 'F');

INSERT INTO infx_col_map
    ( COL_TYPE, TYPE_NAME, ALLOW_NULL )
VALUES
    (263, 'DATE', 'F');

INSERT INTO infx_col_map
    ( COL_TYPE, TYPE_NAME, ALLOW_NULL )
VALUES
    (264, 'MONEY', 'F');

INSERT INTO infx_col_map
    ( COL_TYPE, TYPE_NAME, ALLOW_NULL )
VALUES
    (266, 'DATETIME', 'F');

INSERT INTO infx_col_map
    ( COL_TYPE, TYPE_NAME, ALLOW_NULL )
VALUES
    (267, 'BYTE', 'F');

INSERT INTO infx_col_map
    ( COL_TYPE, TYPE_NAME, ALLOW_NULL )
VALUES
    (268, 'TEXT', 'F');

INSERT INTO infx_col_map
    ( COL_TYPE, TYPE_NAME, ALLOW_NULL )
VALUES
    (269, 'VARCHAR', 'F');

INSERT INTO infx_col_map
    ( COL_TYPE, TYPE_NAME, ALLOW_NULL )
VALUES
    (270, 'INTERVAL', 'F');

INSERT INTO infx_col_map
    ( COL_TYPE, TYPE_NAME, ALLOW_NULL )
VALUES
    (271, 'NCHAR', 'F');

INSERT INTO infx_col_map
    ( COL_TYPE, TYPE_NAME, ALLOW_NULL )
VALUES
    (272, 'NVARCHAR', 'F');


CREATE VIEW user_tab_columns
    (TABLE_NAME, COLUMN_NAME, DATA_TYPE, DATA_LENGTH,
     DATA_PRECISION, DATA_SCALE, NULLABLE, COLUMN_ID)
AS
    SELECT t.tabname, c.colname, i.type_name, c.collength,
           c.collength, c.collength, i.allow_null, c.colno
    FROM   systables t, syscolumns c, infx_col_map i
    WHERE  t.tabid = c.tabid
      AND  c.coltype = i.col_type
;
 
COMMIT WORK;

BEGIN WORK;

drop view PROCESSOR_VIEW
;

create view PROCESSOR_VIEW
as
select
    COMPUTER_SYS.HWARE_SYS_ID,
    TME_OBJECT_ID,
    TME_OBJECT_LABEL,
    PROCESSOR.*
from PROCESSOR, INST_PROCESSOR, COMPUTER_SYS
where   INST_PROCESSOR.PROCESSOR_ID = PROCESSOR.PROCESSOR_ID
and   INST_PROCESSOR.HWARE_SYS_ID = COMPUTER_SYS.HWARE_SYS_ID
;

drop view MEM_VIEW
;

create view MEM_VIEW
as
select
    COMPUTER_SYS_MEM.HWARE_SYS_ID,
    TME_OBJECT_ID,
    TME_OBJECT_LABEL,
    PHYSICAL_MEM_KB,
    PAGING_SPACE_KB,
    COMPUTER_SCANTIME
from COMPUTER_SYS_MEM, COMPUTER_SYS
where COMPUTER_SYS_MEM.HWARE_SYS_ID = COMPUTER_SYS.HWARE_SYS_ID
;

drop view COMPUTER_VIEW
;

create view COMPUTER_VIEW
as
select
    HWARE_SYS_ID,
    TME_OBJECT_ID,
    TME_OBJECT_LABEL,
    COMPUTER_ARCH,
    COMPUTER_MODEL,
    BOOTED_OS_NAME,
    BOOTED_OS_VER
from COMPUTER_SYS
;

drop view INVENTORYDATA
;

create view INVENTORYDATA
as
select
    COMPUTER_SYS.HWARE_SYS_ID,
    COMPUTER_SYS.TME_OBJECT_ID,
    COMPUTER_SYS.TME_OBJECT_LABEL,
    COMPUTER_ARCH,
    COMPUTER_MODEL,
    PHYSICAL_MEM_KB,
    PAGING_SPACE_KB,
    COMPUTER_SCANTIME,
    PROCESSOR_MODEL,
    PROCESSOR_SPEED,
    BOOTED_OS_NAME,
    BOOTED_OS_VER
from
    COMPUTER_SYS, COMPUTER_SYS_MEM, PROCESSOR,
    INST_PROCESSOR
where
    COMPUTER_SYS_MEM.HWARE_SYS_ID =
    COMPUTER_SYS.HWARE_SYS_ID
and
    INST_PROCESSOR.HWARE_SYS_ID =
    COMPUTER_SYS.HWARE_SYS_ID
and
    INST_PROCESSOR.PROCESSOR_ID =
    PROCESSOR.PROCESSOR_ID
;


drop view BASENODE_VIEW
;
create view BASENODE_VIEW
as
select
    HWARE_SYS_ID,
    MANUFACTURER_ID
from HWARE_SYS
;

drop view MANAGEDNODE_VIEW
;
create view MANAGEDNODE_VIEW
as
select
    HWARE_SYS_ID,
    TME_OBJECT_ID,
    TME_OBJECT_LABEL,
    COMPUTER_ARCH,
    BOOTED_OS_NAME,
    BOOTED_OS_VER
from COMPUTER_SYS
;


drop view SW_DIST_VIEW
;

create view SW_DIST_VIEW
as
select
    COMPUTER_SYS.HWARE_SYS_ID,
    COMPUTER_SYS.TME_OBJECT_ID,
    COMPUTER_SYS.TME_OBJECT_LABEL,
    SW_COMP.SW_COMP_NAME,
    SW_COMP.SW_COMP_VER,
    SW_COMP.COMP_LANG_EDITION,
    SW_FPACK.SW_FPACK_ID,
    SW_FPACK.FPACK_TYPE,
    SW_FPACK.FP_SOURCEHOST,
    INST_SW_COMP.INST_FPACK_TIME,
    INST_SW_COMP.ACTION_COMPLETED
from
    COMPUTER_SYS,
    INST_SW_COMP,
    SW_FPACK,
    SW_COMP
where
    INST_SW_COMP.HWARE_SYS_ID = 
    COMPUTER_SYS.HWARE_SYS_ID
  and
    INST_SW_COMP.SW_COMP_NAME =
    SW_COMP.SW_COMP_NAME
  and
    INST_SW_COMP.SW_COMP_VER =
    SW_COMP.SW_COMP_VER
  and
    INST_SW_COMP.COMP_LANG_EDITION =
    SW_COMP.COMP_LANG_EDITION
  and
    SW_COMP.SW_FPACK_ID = 
    SW_FPACK.SW_FPACK_ID  

;


drop view INST_SIG_FILE
;

create view INST_SIG_FILE
as
select
    COMPUTER_SYS.HWARE_SYS_ID,
    SW_SIG_FILE.SIG_FILE_NAME,
    SW_SIG_FILE.SIG_FILE_SIZE,
    INST_UNKNOWN_FILE.INST_FILE_PATH,
    INST_UNKNOWN_FILE.INST_FILE_DATE,
    INST_UNKNOWN_FILE.INST_FILE_TIME,
    INST_UNKNOWN_FILE.CFG_CHG_TIME,
    INST_UNKNOWN_FILE.CFG_CHG_TYPE
from
    COMPUTER_SYS,
    SW_SIG_FILE,
    INST_UNKNOWN_FILE
where
    COMPUTER_SYS.HWARE_SYS_ID =
    INST_UNKNOWN_FILE.HWARE_SYS_ID
and
    INST_UNKNOWN_FILE.INST_FILE_NAME =
    SW_SIG_FILE.SIG_FILE_NAME
and
    INST_UNKNOWN_FILE.INST_FILE_SIZE =
    SW_SIG_FILE.SIG_FILE_SIZE
and 
    (INST_UNKNOWN_FILE.CFG_CHG_TYPE = 'INSERT' or
    INST_UNKNOWN_FILE.CFG_CHG_TYPE = 'UPDATE')
;

drop view INST_SW_COMP_VIEW
;

create view INST_SW_COMP_VIEW
as
select 
    COMPUTER_SYS.TME_OBJECT_ID,
    COMPUTER_SYS.TME_OBJECT_LABEL,
    SW_SIG_FILE.SW_COMP_NAME,
    SW_SIG_FILE.SW_COMP_VER
from 
    COMPUTER_SYS, 
    INST_UNKNOWN_FILE, 
    SW_SIG_FILE
where
    COMPUTER_SYS.HWARE_SYS_ID =
    INST_UNKNOWN_FILE.HWARE_SYS_ID
and 
    SW_SIG_FILE.SIG_FILE_NAME =
    INST_UNKNOWN_FILE.INST_FILE_NAME    
and 
    SW_SIG_FILE.SIG_FILE_SIZE =
    INST_UNKNOWN_FILE.INST_FILE_SIZE    
and 
    (INST_UNKNOWN_FILE.CFG_CHG_TYPE = 'INSERT' or
    INST_UNKNOWN_FILE.CFG_CHG_TYPE = 'UPDATE')
;

drop view INST_SW_VIEW
;

create view INST_SW_VIEW
as
select 
    COMPUTER_SYS.HWARE_SYS_ID,
    COMPUTER_SYS.TME_OBJECT_ID,
    COMPUTER_SYS.TME_OBJECT_LABEL,
    SW_COMP_INSTANCE.SW_ID,
    SW_COMP_INSTANCE.SW_VER_ID,
    SW_SIG_FILE.SIG_FILE_NAME,
    SW_SIG_FILE.SIG_FILE_SIZE
from 
    COMPUTER_SYS, 
    INST_UNKNOWN_FILE, 
    SW_SIG_FILE,
    SW_COMP_INSTANCE
where
    COMPUTER_SYS.HWARE_SYS_ID =
    INST_UNKNOWN_FILE.HWARE_SYS_ID
and 
    SW_SIG_FILE.SIG_FILE_NAME =
    INST_UNKNOWN_FILE.INST_FILE_NAME    
and 
    SW_SIG_FILE.SIG_FILE_SIZE =
    INST_UNKNOWN_FILE.INST_FILE_SIZE    
and 
    SW_COMP_INSTANCE.SW_COMP_NAME =
    SW_SIG_FILE.SW_COMP_NAME 
and
    SW_COMP_INSTANCE.SW_COMP_VER =
    SW_SIG_FILE.SW_COMP_VER
and
    (INST_UNKNOWN_FILE.CFG_CHG_TYPE = 'INSERT' or
    INST_UNKNOWN_FILE.CFG_CHG_TYPE = 'UPDATE')
;


drop view LOG_DRV_VIEW
;

create view LOG_DRV_VIEW
as
select
    COMPUTER_SYS.TME_OBJECT_ID,
    COMPUTER_SYS.TME_OBJECT_LABEL,
    LOG_DRV.*
from
    COMPUTER_SYS,
    LOG_DRV
where
    COMPUTER_SYS.HWARE_SYS_ID =
    LOG_DRV.HWARE_SYS_ID
and
    LOG_DRV.CFG_CHG_TYPE != 'DELETE'
;

drop view INST_HDISK_VIEW
;

create view INST_HDISK_VIEW
as
select
    INST_HDISK.HWARE_SYS_ID,
    COMPUTER_SYS.TME_OBJECT_ID,
    COMPUTER_SYS.TME_OBJECT_LABEL,
    HDISK.*,
    INST_HDISK.HDISK_SER_NUM
from
    COMPUTER_SYS,
    HDISK,
    INST_HDISK
where
    COMPUTER_SYS.HWARE_SYS_ID =
    INST_HDISK.HWARE_SYS_ID
and
    INST_HDISK.HDISK_ID =
    HDISK.HDISK_ID
;

drop view NET_NODE_VIEW
;

create view NET_NODE_VIEW
as
select
    COMPUTER_SYS.TME_OBJECT_ID,
    COMPUTER_SYS.TME_OBJECT_LABEL,
    NET_NODE.*
from
    COMPUTER_SYS,
    NET_NODE
where
    COMPUTER_SYS.HWARE_SYS_ID =
    NET_NODE.HWARE_SYS_ID
;

drop view INVENTORY_SYS_VIEW
;

create view INVENTORY_SYS_VIEW
as
select
    INVENTORYDATA.*,
    INST_SW_VIEW.SW_ID,
    INST_SW_VIEW.SW_VER_ID
from
    INVENTORYDATA,
    INST_SW_VIEW
where
    INVENTORYDATA.TME_OBJECT_ID =
    INST_SW_VIEW.TME_OBJECT_ID
;

drop view INST_FILE_VIEW
;

create view INST_FILE_VIEW
as
select
    COMPUTER_SYS.TME_OBJECT_ID,
    COMPUTER_SYS.TME_OBJECT_LABEL,
    INST_UNKNOWN_FILE.*
from
    COMPUTER_SYS,
    INST_UNKNOWN_FILE
where
    COMPUTER_SYS.HWARE_SYS_ID =
    INST_UNKNOWN_FILE.HWARE_SYS_ID
;

drop view INST_FLPY_DRV_VIEW
;

create view INST_FLPY_DRV_VIEW
as
select
    COMPUTER_SYS.TME_OBJECT_ID,
    COMPUTER_SYS.TME_OBJECT_LABEL,
    INST_FLPY_DRV.*,
    FLPY_DRV.FLPY_DRV_TYPE
from
    COMPUTER_SYS,
    INST_FLPY_DRV,
    FLPY_DRV
where
    COMPUTER_SYS.HWARE_SYS_ID =
    INST_FLPY_DRV.HWARE_SYS_ID
and
    INST_FLPY_DRV.FLPY_DRV_ID =
    FLPY_DRV.FLPY_DRV_ID
;

drop view INST_MOUSE_VIEW
;

create view INST_MOUSE_VIEW
as
select
    COMPUTER_SYS.TME_OBJECT_ID,
    COMPUTER_SYS.TME_OBJECT_LABEL,
    INST_MOUSE.*
from
    COMPUTER_SYS,
    INST_MOUSE
where
    COMPUTER_SYS.HWARE_SYS_ID =
    INST_MOUSE.HWARE_SYS_ID
;

drop view INST_KEYBOARD_VIEW
;

create view INST_KEYBOARD_VIEW
as
select
    COMPUTER_SYS.TME_OBJECT_ID,
    COMPUTER_SYS.TME_OBJECT_LABEL,
    INST_KEYBOARD.*
from
    COMPUTER_SYS,
    INST_KEYBOARD
where
    COMPUTER_SYS.HWARE_SYS_ID =
    INST_KEYBOARD.HWARE_SYS_ID
;

drop view INST_COPROC_VIEW
;

create view INST_COPROC_VIEW
as
select
    COMPUTER_SYS.TME_OBJECT_ID,
    COMPUTER_SYS.TME_OBJECT_LABEL,
    INST_COPROC.*
from
    COMPUTER_SYS,
    INST_COPROC
where
    COMPUTER_SYS.HWARE_SYS_ID =
    INST_COPROC.HWARE_SYS_ID
;

drop view NT_INFO_VIEW
;

create view NT_INFO_VIEW
as
select
    COMPUTER_SYS.TME_OBJECT_ID,
    COMPUTER_SYS.TME_OBJECT_LABEL,
    NT_INFO.*
from
    COMPUTER_SYS,
    NT_INFO
where
    COMPUTER_SYS.HWARE_SYS_ID =
    NT_INFO.HWARE_SYS_ID
;

drop view NWARE_SERVER_VIEW
;

create view NWARE_SERVER_VIEW
as
select
    COMPUTER_SYS.TME_OBJECT_ID,
    COMPUTER_SYS.TME_OBJECT_LABEL,
    NWARE_SERVER.*
from
    COMPUTER_SYS,
    NWARE_SERVER
where
    COMPUTER_SYS.HWARE_SYS_ID =
    NWARE_SERVER.HWARE_SYS_ID
;

drop view PC_MEM_VIEW
;

create view PC_MEM_VIEW
as
select
    COMPUTER_SYS.TME_OBJECT_ID,
    COMPUTER_SYS.TME_OBJECT_LABEL,
    PC_MEM.*
from
    COMPUTER_SYS,
    PC_MEM
where
    COMPUTER_SYS.HWARE_SYS_ID =
    PC_MEM.HWARE_SYS_ID
;

drop view PC_DRV_SVC_VIEW
;

create view PC_DRV_SVC_VIEW
as
select
    COMPUTER_SYS.TME_OBJECT_ID,
    COMPUTER_SYS.TME_OBJECT_LABEL,
    PC_DEV_DRVS.*
from
    COMPUTER_SYS,
    PC_DEV_DRVS
where
    COMPUTER_SYS.HWARE_SYS_ID =
    PC_DEV_DRVS.HWARE_SYS_ID
;

drop view PC_BIOS_VIEW
;

create view PC_BIOS_VIEW
as
select
    COMPUTER_SYS.TME_OBJECT_ID,
    COMPUTER_SYS.TME_OBJECT_LABEL,
    INST_BIOS.*
from
    COMPUTER_SYS,
    INST_BIOS
where
    COMPUTER_SYS.HWARE_SYS_ID =
    INST_BIOS.HWARE_SYS_ID
;

drop view PC_LAN_VIEW
;

create view PC_LAN_VIEW
as
select
    COMPUTER_SYS.TME_OBJECT_ID,
    COMPUTER_SYS.TME_OBJECT_LABEL,
    PC_IPX_LAN.*
from
    COMPUTER_SYS,
    PC_IPX_LAN
where
    COMPUTER_SYS.HWARE_SYS_ID =
    PC_IPX_LAN.HWARE_SYS_ID
;

drop view PC_LAN_CONN_VIEW
;

create view PC_LAN_CONN_VIEW
as
select
    COMPUTER_SYS.TME_OBJECT_ID,
    COMPUTER_SYS.TME_OBJECT_LABEL,
    PC_IPX_LAN_CONX.*
from
    COMPUTER_SYS,
    PC_IPX_LAN_CONX
where
    COMPUTER_SYS.HWARE_SYS_ID =
    PC_IPX_LAN_CONX.HWARE_SYS_ID
;

drop view INST_CFG_FILE_VIEW
;

create view INST_CFG_FILE_VIEW
as
select
    COMPUTER_SYS.TME_OBJECT_ID,
    COMPUTER_SYS.TME_OBJECT_LABEL,
    INST_CFG_FILE.*
from
    COMPUTER_SYS,
    INST_CFG_FILE
where
    COMPUTER_SYS.HWARE_SYS_ID =
    INST_CFG_FILE.HWARE_SYS_ID
and
    INST_CFG_FILE.CFG_CHG_TYPE != 'DELETE'
;

drop view PC_PORTS_VIEW
;

create view PC_PORTS_VIEW
as
select
    COMPUTER_SYS.TME_OBJECT_ID,
    COMPUTER_SYS.TME_OBJECT_LABEL,
    PC_PORTS.*
from
    COMPUTER_SYS,
    PC_PORTS
where
    COMPUTER_SYS.HWARE_SYS_ID =
    PC_PORTS.HWARE_SYS_ID
;

drop view INST_NET_CARD_VIEW
;

create view INST_NET_CARD_VIEW
as
select
    COMPUTER_SYS.TME_OBJECT_ID,
    COMPUTER_SYS.TME_OBJECT_LABEL,
    NET_CARD.*
from
    COMPUTER_SYS,
    INST_DEV_CARD,
    NET_CARD
where
    COMPUTER_SYS.HWARE_SYS_ID =
    INST_DEV_CARD.HWARE_SYS_ID
and
    INST_DEV_CARD.DEV_CARD_ID =
    NET_CARD.DEV_CARD_ID
;

drop view INST_VID_CARD_VIEW
;

create view INST_VID_CARD_VIEW
as
select
    COMPUTER_SYS.TME_OBJECT_ID,
    COMPUTER_SYS.TME_OBJECT_LABEL,
    VID_CARD.*
from
    COMPUTER_SYS,
    INST_DEV_CARD,
    VID_CARD
where
    COMPUTER_SYS.HWARE_SYS_ID =
    INST_DEV_CARD.HWARE_SYS_ID
and
    INST_DEV_CARD.DEV_CARD_ID =
    VID_CARD.DEV_CARD_ID
;

drop view LSCAN_SW_FILE_VIEW
;

create view LSCAN_SW_FILE_VIEW
as
select
    COMPUTER_SYS.TME_OBJECT_ID,
    COMPUTER_SYS.TME_OBJECT_LABEL,
    INST_UNKNOWN_FILE.*
from
    COMPUTER_SYS,
    INST_UNKNOWN_FILE
where
    COMPUTER_SYS.HWARE_SYS_ID =
    INST_UNKNOWN_FILE.HWARE_SYS_ID
and
    COMPUTER_SYS.COMPUTER_SCANTIME =
    INST_UNKNOWN_FILE.CFG_CHG_TIME
;

drop view LSCAN_CFG_FILES
;

create view LSCAN_CFG_FILES
as
select
    COMPUTER_SYS.TME_OBJECT_ID,
    COMPUTER_SYS.TME_OBJECT_LABEL,
    INST_CFG_FILE.*
from
    COMPUTER_SYS,
    INST_CFG_FILE
where
    COMPUTER_SYS.HWARE_SYS_ID =
    INST_CFG_FILE.HWARE_SYS_ID
and
    COMPUTER_SYS.COMPUTER_SCANTIME =
    INST_CFG_FILE.CFG_CHG_TIME
;

COMMIT WORK;

BEGIN WORK;

insert into QUERY_VIEWS (VIEW_NAME) values ('INVENTORYDATA')
;
insert into QUERY_VIEWS (VIEW_NAME) values ('INST_SW_VIEW')
;
insert into QUERY_VIEWS (VIEW_NAME) values ('LOG_DRV_VIEW')
;
insert into QUERY_VIEWS (VIEW_NAME) values ('INST_HDISK_VIEW')
;
insert into QUERY_VIEWS (VIEW_NAME) values ('NET_NODE_VIEW')
;
insert into QUERY_VIEWS (VIEW_NAME) values ('INVENTORY_SYS_VIEW')
;
insert into QUERY_VIEWS (VIEW_NAME) values ('INST_FILE_VIEW')
;
insert into QUERY_VIEWS (VIEW_NAME) values ('INST_FLPY_DRV_VIEW')
;
insert into QUERY_VIEWS (VIEW_NAME) values ('INST_KEYBOARD_VIEW')
;
insert into QUERY_VIEWS (VIEW_NAME) values ('INST_MOUSE_VIEW')
;
insert into QUERY_VIEWS (VIEW_NAME) values ('INST_COPROC_VIEW')
;
insert into QUERY_VIEWS (VIEW_NAME) values ('INST_VID_CARD_VIEW')
;
insert into QUERY_VIEWS (VIEW_NAME) values ('INST_NET_CARD_VIEW')
;
insert into QUERY_VIEWS (VIEW_NAME) values ('PC_BIOS_VIEW')
;
insert into QUERY_VIEWS (VIEW_NAME) values ('PC_PORTS_VIEW')
;
insert into QUERY_VIEWS (VIEW_NAME) values ('PC_MEM_VIEW')
;
insert into QUERY_VIEWS (VIEW_NAME) values ('PC_LAN_VIEW')
;
insert into QUERY_VIEWS (VIEW_NAME) values ('PC_LAN_CONN_VIEW')
;
insert into QUERY_VIEWS (VIEW_NAME) values ('PC_DRV_SVC_VIEW')
;
insert into QUERY_VIEWS (VIEW_NAME) values ('NT_INFO_VIEW')
;
insert into QUERY_VIEWS (VIEW_NAME) values ('NWARE_SERVER_VIEW')
;
insert into QUERY_VIEWS (VIEW_NAME) values ('INST_CFG_FILE_VIEW')
;
insert into QUERY_VIEWS (VIEW_NAME) values ('LSCAN_SW_FILE_VIEW')
;
insert into QUERY_VIEWS (VIEW_NAME) values ('LSCAN_CFG_FILES')
;

drop view SWDISTDATA_VIEW
;

create view SWDISTDATA_VIEW
as
select
    TME_OBJECT_ID,
    TME_OBJECT_LABEL,
    SW_COMP.SW_COMP_NAME,
    SW_COMP.SW_COMP_VER,
    SW_FPACK.SW_FPACK_ID,
    SW_FPACK.FPACK_TYPE,
    SW_FPACK.FP_SOURCEHOST,
    INST_SW_COMP.INST_FPACK_TIME,
    INST_SW_COMP.INST_FPACK_PATH,
    INST_SW_COMP.FPACK_ACTIVATED,
    INST_SW_COMP.FPACK_ACTIV_TIME,
    INST_SW_COMP.TME_ADMIN_ID,
    INST_SW_COMP.ACTION_COMPLETED
from SW_COMP, INST_SW_COMP, SW_FPACK, COMPUTER_SYS
where 
      SW_COMP.SW_FPACK_ID = 
      SW_FPACK.SW_FPACK_ID
and   
      INST_SW_COMP.HWARE_SYS_ID = 
      COMPUTER_SYS.HWARE_SYS_ID
and   
      INST_SW_COMP.SW_COMP_NAME = 
      SW_COMP.SW_COMP_NAME 
and   
      INST_SW_COMP.SW_COMP_VER = 
      SW_COMP.SW_COMP_VER 
;

insert into QUERY_VIEWS (VIEW_NAME) values ('SWDISTDATA_VIEW')
;

drop view INST_OS_DET_VIEW
;

create view INST_OS_DET_VIEW
as
select
    COMPUTER_SYS.TME_OBJECT_ID,
    COMPUTER_SYS.TME_OBJECT_LABEL,
    INST_OS_DETAILS.*
from
    COMPUTER_SYS,
    INST_OS_DETAILS
where
    COMPUTER_SYS.HWARE_SYS_ID =
    INST_OS_DETAILS.HWARE_SYS_ID
;

insert into QUERY_VIEWS (VIEW_NAME) values ('INST_OS_DET_VIEW')
;

drop view INST_PC_SW_VIEW
;

create view INST_PC_SW_VIEW
as
select 
    COMPUTER_SYS.HWARE_SYS_ID,
    COMPUTER_SYS.TME_OBJECT_ID,
    COMPUTER_SYS.TME_OBJECT_LABEL,
    SW_COMP_INSTANCE.SW_ID,
    SW_COMP_INSTANCE.SW_VER_ID,
    SW_SIG_FILE.SIG_FILE_NAME,
    SW_SIG_FILE.SIG_FILE_SIZE
from 
    COMPUTER_SYS, 
    INST_UNKNOWN_FILE, 
    SW_SIG_FILE,
    SW_COMP_INSTANCE
where
    COMPUTER_SYS.HWARE_SYS_ID =
    INST_UNKNOWN_FILE.HWARE_SYS_ID
and 
    SW_SIG_FILE.SIG_FILE_NAME =
    INST_UNKNOWN_FILE.INST_FILE_NAME
and 
    SW_SIG_FILE.SIG_FILE_SIZE =
    INST_UNKNOWN_FILE.INST_FILE_SIZE    
and 
    SW_COMP_INSTANCE.SW_COMP_NAME =
    SW_SIG_FILE.SW_COMP_NAME 
and
    SW_COMP_INSTANCE.SW_COMP_VER =
    SW_SIG_FILE.SW_COMP_VER
and
    (INST_UNKNOWN_FILE.CFG_CHG_TYPE = 'INSERT' or
    INST_UNKNOWN_FILE.CFG_CHG_TYPE = 'UPDATE')
;

insert into QUERY_VIEWS (VIEW_NAME) values ('INST_PC_SW_VIEW')
;

drop view NOSIG_FILES_VIEW
;

create view NOSIG_FILES_VIEW
as
select
      HWARE_SYS_ID,
      INST_FILE_NAME,
      INST_FILE_SIZE
from
      INST_UNKNOWN_FILE A
where
      not exists
      (select 'X'
         from SW_SIG_FILE B
        where A.INST_FILE_NAME = B.SIG_FILE_NAME
          and A.INST_FILE_SIZE = B.SIG_FILE_SIZE)
;

insert into QUERY_VIEWS (VIEW_NAME) values ('NOSIG_FILES_VIEW')
;

COMMIT WORK;

-----------------------------
-- Foreign Key Constraints --
-----------------------------
BEGIN WORK;

alter table COMPUTER_SYS
    add constraint 
    foreign key (HWARE_SYS_ID)
    references HWARE_SYS(HWARE_SYS_ID)
    on delete cascade
    constraint COMP_SYS_FK;

alter table DESKTOP_PC
    add constraint
    foreign key (HWARE_SYS_ID)
    references HWARE_SYS(HWARE_SYS_ID)
    on delete cascade
    constraint DESKTOP_PC_FK;

alter table PC_PORTS
    add constraint
    foreign key (HWARE_SYS_ID)
    references DESKTOP_PC(HWARE_SYS_ID)
    on delete cascade
    constraint PC_PORTS_FK;

alter table PC_MEM
    add constraint
    foreign key (HWARE_SYS_ID)
    references DESKTOP_PC(HWARE_SYS_ID)
    on delete cascade
    constraint PC_MEMORY_FK;

alter table PC_IPX_LAN_CONX
    add constraint
    foreign key (HWARE_SYS_ID)
    references DESKTOP_PC(HWARE_SYS_ID)
    on delete cascade
    constraint PC_IPX_CONN_FK;

alter table PC_IPX_LAN
    add constraint
    foreign key (HWARE_SYS_ID)
    references DESKTOP_PC(HWARE_SYS_ID)
    on delete cascade
    constraint PC_IPX_LAN_FK;

alter table PC_DEV_DRVS
    add constraint
    foreign key (HWARE_SYS_ID)
    references DESKTOP_PC(HWARE_SYS_ID)
    on delete cascade
    constraint PC_DEV_DRV_FK;

alter table PC_BIOS
    add constraint
    foreign key (HWARE_SYS_ID)
    references DESKTOP_PC(HWARE_SYS_ID)
    on delete cascade
    constraint PC_BIOS_FK;

alter table NET_NODE
    add constraint
    foreign key (HWARE_SYS_ID)
    references HWARE_SYS(HWARE_SYS_ID)
    on delete cascade
    constraint NETWORK_NODE_FK;

alter table LOG_DRV
    add constraint
    foreign key (HWARE_SYS_ID)
    references HWARE_SYS(HWARE_SYS_ID)
    on delete cascade
    constraint LOG_DRV_FK;

alter table INST_FLPY_DRV
    add constraint
    foreign key (HWARE_SYS_ID)
    references COMPUTER_SYS(HWARE_SYS_ID)
    on delete cascade
    constraint INST_FLPY_DRV_FK;

alter table INST_MONITOR
    add constraint
    foreign key (HWARE_SYS_ID)
    references COMPUTER_SYS(HWARE_SYS_ID)
    on delete cascade
    constraint INST_MONITOR_FK;

alter table INST_PRINTER
    add constraint
    foreign key (HWARE_SYS_ID)
    references COMPUTER_SYS(HWARE_SYS_ID)
    on delete cascade
    constraint INST_PRINTER_FK;

alter table INST_TAPE_DRV
    add constraint
    foreign key (HWARE_SYS_ID)
    references COMPUTER_SYS(HWARE_SYS_ID)
    on delete cascade
    constraint INST_TAPE_DRV_FK;

alter table INST_UNKNOWN_FILE
    add constraint
    foreign key (HWARE_SYS_ID)
    references HWARE_SYS(HWARE_SYS_ID)
    on delete cascade
    constraint INST_UNKNOWN_FK;

alter table INST_RWOPT_DRV
    add constraint
    foreign key (HWARE_SYS_ID)
    references COMPUTER_SYS(HWARE_SYS_ID)
    on delete cascade
    constraint INST_RWOPT_DRV_FK;

alter table INST_PROCESSOR
    add constraint
    foreign key (HWARE_SYS_ID)
    references COMPUTER_SYS(HWARE_SYS_ID)
    on delete cascade
    constraint INST_PROC_FK;

alter table INST_OS_DETAILS
    add constraint
    foreign key (HWARE_SYS_ID)
    references HWARE_SYS(HWARE_SYS_ID)
    on delete cascade
    constraint INST_OS_FK;

alter table INST_MOUSE
    add constraint
    foreign key (HWARE_SYS_ID)
    references COMPUTER_SYS(HWARE_SYS_ID)
    on delete cascade
    constraint INST_MOUSE_FK;

alter table INST_KEYBOARD
    add constraint
    foreign key (HWARE_SYS_ID)
    references COMPUTER_SYS(HWARE_SYS_ID)
    on delete cascade
    constraint INST_KYBD_FK;

alter table INST_HDISK
    add constraint
    foreign key (HWARE_SYS_ID)
    references COMPUTER_SYS(HWARE_SYS_ID)
    on delete cascade
    constraint INST_HDISK_FK;

alter table INST_DEV_CARD
    add constraint
    foreign key (HWARE_SYS_ID)
    references COMPUTER_SYS(HWARE_SYS_ID)
    on delete cascade
    constraint INST_DEV_CARD_FK;

alter table INST_CFG_FILE
    add constraint
    foreign key (HWARE_SYS_ID)
    references HWARE_SYS(HWARE_SYS_ID)
    on delete cascade
    constraint INST_CFG_FILE_FK;

alter table INST_CDROM_DRV
    add constraint
    foreign key (HWARE_SYS_ID)
    references COMPUTER_SYS(HWARE_SYS_ID)
    on delete cascade
    constraint INST_CDROM_DRV_FK;

alter table  COMPUTER_SYS_MEM
    add constraint
    foreign key (HWARE_SYS_ID)
    references HWARE_SYS(HWARE_SYS_ID)
    on delete cascade
    constraint COMP_SYS_MEM_FK;

alter table NT_INFO
    add constraint
    foreign key (HWARE_SYS_ID)
    references HWARE_SYS(HWARE_SYS_ID)
    on delete cascade
    constraint NT_INFO_FK;

alter table NW_VOLUMES
    add constraint
    foreign key (HWARE_SYS_ID)
    references HWARE_SYS(HWARE_SYS_ID)
    on delete cascade
    constraint NW_VOL_FK;

alter table NWARE_SERVER
    add constraint
    foreign key (HWARE_SYS_ID)
    references HWARE_SYS(HWARE_SYS_ID)
    on delete cascade
    constraint NW_SRV_FK;

alter table UNIX_SERVER
    add constraint
    foreign key (HWARE_SYS_ID)
    references HWARE_SYS(HWARE_SYS_ID)
    on delete cascade
    constraint UNIX_SERVER_FK;

alter table SW_VER
    add constraint
    foreign key (SW_ID)
    references SW(SW_ID)
    on delete cascade
    constraint SW_VER_FK;

alter table SW_COMP_INSTANCE
    add constraint
    foreign key (SW_COMP_NAME, SW_COMP_VER, COMP_LANG_EDITION)
    references SW_COMP(SW_COMP_NAME, SW_COMP_VER, COMP_LANG_EDITION)
    on delete cascade
    constraint SW_COMP_INST_FK; 

alter table SW_COMP_INSTANCE
    add constraint
    foreign key (SW_VER_ID, SW_ID, VER_LANG_EDITION)
    references SW_VER(SW_VER_ID, SW_ID, VER_LANG_EDITION)
    on delete cascade
    constraint SW_COMP_VER_FK; 


alter table SW_SIG_FILE
    add constraint
    foreign key (SW_COMP_NAME, SW_COMP_VER, COMP_LANG_EDITION)
    references SW_COMP(SW_COMP_NAME, SW_COMP_VER, COMP_LANG_EDITION)
    on delete cascade
    constraint SW_SIG_FILE_FK;
    
alter table INST_COPROC
    add constraint
    foreign key (HWARE_SYS_ID)
    references HWARE_SYS(HWARE_SYS_ID)
    on delete cascade
    constraint INST_COPROC_FK;

alter table INST_BIOS
    add constraint
    foreign key (HWARE_SYS_ID)
    references HWARE_SYS(HWARE_SYS_ID)
    on delete cascade
    constraint INST_BIOS_FK;

COMMIT WORK;
